#
# spec file for package texstudio
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           texstudio
Version:        4.3.1
Release:        bp155.1.2
Summary:        LaTeX Editor
License:        Apache-2.0 AND GPL-2.0-only AND GPL-3.0-only AND MPL-1.1
Group:          Productivity/Publishing/TeX/Frontends
URL:            https://www.texstudio.org
Source0:        https://github.com/texstudio-org/texstudio/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Qml)
BuildRequires:  pkgconfig(Qt5Script)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5UiTools)
BuildRequires:  pkgconfig(poppler-qt5)
Requires:       hunspell
Requires:       texlive-latex

%description
TeXstudio is a program based on texmaker, that integrates many tools needed
to develop documents with LaTeX, in just one application. Using its editor
you can write your documents with the help of interactive spell checking,
syntax highlighting, automatically code completion and more.

%prep
%setup -q

%build
%ifarch aarch64 %{arm} s390x
%define crashhandler NO_CRASH_HANDLER=true
%endif

%qmake5 CONFIG-=debug %{?crashhandler} texstudio.pro
%make_jobs

%install
make INSTALL_ROOT=%{buildroot} install

rm -f %{buildroot}%{_datadir}/texstudio/{AUTHORS,COPYING,CHANGELOG.txt}
%fdupes -s %{buildroot}%{_datadir}/texstudio/

%files
%license utilities/COPYING
%doc utilities/AUTHORS utilities/manual/CHANGELOG.txt
%{_bindir}/texstudio
%{_datadir}/texstudio/
%{_datadir}/applications/texstudio.desktop
%{_datadir}/icons/hicolor/scalable/apps/texstudio.svg
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/texstudio.metainfo.xml

%changelog
* Sat Aug 27 2022 Markus Ebner <info@ebner-markus.de>
- Update to version 4.3.1
  * fix loading files various times if relative path is used for \include (#2533)
  * fix custom verbatim highlighting (#2528)
  * fix label highlighting (#2512)
* Mon Aug 22 2022 Markus Ebner <info@ebner-markus.de>
- Update to version 4.3.0
  * show most used command at first place in completer
  * more cwls
  * get position into clipboard in pdf on ctrl+shift+click (#2623)
  * copy/paste table content into table/matrix wizard
  * move to next/previous word now stops at every delimiter (no skip over several brackets) #2311
  * build qt6/win for win10+
  * small bug fixes
* Sun Apr 17 2022 Markus Ebner <info@ebner-markus.de>
- Update to version 4.2.3
  * fix unable to save under special circumstances (#2124)
  * fix stuck to save unsaved document (only in explicit root mode and with a new unsaved document,#2153)
  * xindex engine added
  * fix math highlighting in keyvals (#2138)
  * add context menu in embbeded pdf viewer to invert pdf colors
  * remember window state (maximized/normal) of config dialog
  * fix (and speed-up) miktex package detection
  * fix handling apostrophed words better in spellchecker (#2179)
  * regular expression in extended search behave the same as in normal search
  * more cwls
* Tue Mar 15 2022 Markus Ebner <info@ebner-markus.de>
- Update to version 4.2.2
  * more cwls
  * fix crash, #2094, #2084, #2109
  * use picture highlighting for tikz env and similar
* Sun Jan 30 2022 Avinesh Kumar <avinesh.kumar@suse.com>
- Update to version 4.2.1
  * fix placeholder issues
  * fix handling mirrored placeolder, like in issue #2063
  * handle NewDocumentsCommand better for completer
  * enable "open in explorer" again
  * fix building for poppler >=22.x
  * more cwls
* Sat Jan 22 2022 Markus Ebner <info@ebner-markus.de>
- Update to version 4.2.0
  * more cwls
  * fix key handling for some special keyboard set-ups (#2011)
  * fix user menu handling
  * filter available dictionaries in status/language selection
  * change placeHolder behavior: autoremove when content in placeholder
    is changed, don't use placeholder for cutBuffer
* Wed Dec 29 2021 Fusion Future <qydwhotmail@gmail.com>
- Update to version 4.1.2
  * allow resizing the different sections in the symbol widget
  * fix automatic session restore on OSX/Qt6
* Thu Nov 25 2021 Markus Ebner <info@ebner-markus.de>
- Update to version 4.1.2
  * allow resizing the different sections in the symbol widget
  * fix automatic session restore on OSX/Qt6
- Update to version 4.1.1
  * fix weird OSX issue that cursor keys were not working
  * allow maximise config dialog
- Update to version 4.1.0
  * change session format to json in order to circumvent OSX/Qt6 issue
  * fix input box for chinese (#1896)
  * fix update of pdf fit to text width (#1935)
  * make edview accessible from js
- Update to version 4.0.4
  * use QT6.2.1 on OSX, fix crash when checking for updates, fix restoring last session
  * better pdf font substitution on windows (#1812)
  * fix placing cursor for large fonts (#1908)
  * more cwls
- Update to version 4.0.3
  * fix linewidth calculation in Qt6
  * fix crash on load/new doc (under unknown,system specific circumstances)
  * remove placeholder quicker
  * more cwls
* Fri Oct 22 2021 Markus Ebner <info@ebner-markus.de>
- Update to version 4.0.2
  * fix structure view (inlcudes and cursor marking, #1828)
  * fix completer tooltip on bibids (#1835)
  * OSX: fix "slanted" cursor (#1836)
  * more cwls
- Update to version 4.0.1
  * add more cwls
  * fix pdfviewer page display
  * build OSX with QT6.2, fix special charcters entry (alt+n + n , etc.) (#1770)
  * activate crash handler on win again
  * fix strcuture detection for included files
* Tue Sep 28 2021 Markus Ebner <info@ebner-markus.de>
- Update to version 4.0.0
  * adapt to Qt6/poppler-qt6
  * OSX/win build provided with Qt6
  * remodel structure handling in order to avoid (rare) crashes
  * more and updated completion word lists thanks to mbertucci47
  * handle text (e.g. \text{text}) in mathenv as text with spell checking
  * performance improvement for large files with large number of labels and/or large number of includes
  * fix that search options are persistant
  * automatic structure scrolling can be turned off (#1742)
  * some bug fixes
* Mon May 17 2021 Fusion Future <qydwhotmail@gmail.com>
- Disable crash handler on s390x to fix build error
- Update to version 3.1.2
  * completed global TOC (background color coded, can be adjusted in config)
  * fontawesome5 symbol pane
  * another dark theme style (Orion Dark)
  * slightly modernised windows installer
  * smaller windows binaries
  * fix menu changes by user
  * fix root document detection when symbolic links of symbolic links are involved (#1505)
  * fix disabled parentheses autocompletion after certain completer actions (#1347)
  * results from styleparser gets immediately updated
* Mon Feb 22 2021 Markus Ebner <info@ebner-markus.de>
- Update to version 3.1.1
  * fix crashes concerning opening included files
  * let global TOC update as you type
- Update to version 3.1.0
  * fix changing GUI language
  * global TOC added which needs to be updated for now (WIP)
* Tue Feb 16 2021 Markus Ebner <info@ebner-markus.de>
- Update to version 3.0.5
  * fix crash when deleting all elements of a build chain (#1415)
  * fix large tooltips on win with ADWAITA style
  * number of pdf rendering threads limited to 8 (or to set value, see #1463)
  * add command line option --texpath to force a tex path
  * fix touchpad scroll in x direction
  * fix a seldom crash
  * adapt speller dialog to find the same errors as the online checker
  * fix replace in global search
* Wed Jan  6 2021 Dirk Müller <dmueller@suse.com>
- update to 3.0.4:
  - fix crash when deleting all elements of a build chain (#1415)
  - fix RTL presentation when zoomed (#1404)
  - fix pdf toolbar size setting
* Tue Dec 29 2020 Markus Ebner <info@ebner-markus.de>
- Update to version 3.0.3
  * iOS bugfixes
- Update to version 3.0.2
  * handle \tabularnewline correctly (#1373)
  * fix text insertion on selected text (#1359&#1354)
  * changed behaviour for cut buffer and Ctrl+e (insert env)(#1342)
  * texdoc added as selectable command
  * win build now uses 64 bit and can handle larger documents
  * larger number of default dictionaries added
* Tue Sep  8 2020 Markus Ebner <info@ebner-markus.de>
- Update to version 3.0.1
  * fix glitch in modern style (#1238, triangle missing)
  * fix equation preview (#1234)
  * fix commands with quotes (#1225 & #1169)
  * fix syntax marker in darkmode (#1224)
* Wed Aug 26 2020 Dmitry Roshchin <dmitry_r@opensuse.org>
- Update to version 3.0.0
  * speed up document parsing, should result in faster document load times
  * spell checking is done asynchronously
  * custom verbatim/math env highlighting abandoned for a cwl based approach
  * better dark-mode support
* Thu Jan 23 2020 Markus Ebner <info@ebner-markus.de>
- Update to version 2.12.22
  * fixes garbled symbols in OSX
  * fixes crash when changing magic language comment and pdf search path handling.
  * last release supporting Qt4
* Wed Jan 15 2020 Markus Ebner <info@ebner-markus.de>
- Update to version 2.12.20
  * fixes a problem with replacing when search highlight is activated
* Wed Jan  8 2020 Markus Ebner <info@ebner-markus.de>
- Update to version 2.12.18
  * mainly a bug fix release
  * better support of regexp in search
* Mon May 20 2019 Markus Ebner <info@ebner-markus.de>
- Update to version 2.12.16
  * mainly a bug fix release.
  * most notable change is flickerfree update of pdf
* Wed May 15 2019 Markus Ebner <info@ebner-markus.de>
- Update to version 2.12.14
  * fix bug that not all available GUI languages are shown
  * tweak fuzzy completer
  * fix template presentation
- Update to version 2.12.12
  * improve macro handling, provide gui that directly downloads macros from github.com/texstudio-org/texstudio-macro
  * add fuzzy completion mode
  * add cwls
  * fix rare bug that the character appear reverse order
  * bug fixes
* Mon Jul 16 2018 mpluskal@suse.com
- Use source url
- Drop conditionals for older distros, they fail to build anyways
- Use spec-cleaner to modernise spec file
* Sun Jul 15 2018 enzokiel@kabelmail.de
- Update to version 2.12.10
  * bug fixes
  * fix structure view with Qt >5.10
- Update to version 2.12.8
  * improved tokenizer for syntax checking and completion
  * pressing Ctrl+F while the editor search has focus opens the
    extended search, i.e., you'll get extended search by pressing
    Ctrl+F twice
  * automatically insert math delimiters ($) when inserting a math
    command outside of a math env (can be turned off, default on)
  * change copy behavior of multiple cursors from selection order
    to line order
  * file list is now a transparent popup window: closes when clicked
    outside
  * combine file conflict and show diff dialog
  * fix file watcher not recognizing multiple changes to a file in
    quick succession
  * improved detection of package names when opening texdoc
  * new symbol panel layout
  * some touch scrolling on certain panels
  * updated synctex and poppler libraries for pdf viewer
  * fix undo when a snippet is inserted and a selection is inserted
    as well
  * fix some parts of the editor background may not be drawn in the
    correct color
  * build for OSX High Sierra
  * various other fixes
* Thu Jan  4 2018 stefan.bruens@rwth-aachen.de
- Unbreak build on Leap 42.x, make_jobs is only provided by macros.qt5
* Wed Jan  3 2018 stefan.bruens@rwth-aachen.de
- Disable crash handler on aarch64/armv6l/armv7l, aarch64 is
  not implemented and armv6l/armv7l is broken
- use %%qmake5 macro to supply CXXFLAGS and also CFLAGS
* Tue Aug 22 2017 dmitry_r@opensuse.org
- Update to version 2.12.6
  * Minor changes
* Mon Feb  6 2017 opensuse@kulawiak.de
- Update to version 2.12.2
  * PDF shortcuts are now changable
  * improved user interface: optimized layout, some new icons, some changes of color
  * warn if file-saving fails
  * Support LanguageTool json API (needed for LanguageTool > 3.5)
* Sun Oct 30 2016 opensuse@kulawiak.de
- Update to version 2.11.2
  * major performance speedup
  * speed up pasting into large documents (factor 100x)
  * add comment toggle
  * improved search panel layout
  * improved bracket detection for \todo highlighting (bug 1789)
  * improved parsing of section titles (bug 1817)
  * bugfixes and minor changes, see included CHANGELOG.txt for details
* Sun Jun  5 2016 dmitry_r@opensuse.org
- Set minimal required memory for building: 2500 Mb
* Sat Jun  4 2016 dmitry_r@opensuse.org
- Update to version 2.11.0
  * support two editors next to each other
  * new tabular wizard
  * support multi-line commands
  * add scrollbar marks for search and bookmarks
  * add command option --no-session
  * bugfixes and minor changes, see included CHANGELOG.txt for details
* Tue Feb  9 2016 mail@bernhard-voelker.de
- Update to version 2.10.8:
  * bugfix release, see included CHANGELOG.txt for details
* Wed Jan 13 2016 mail@bernhard-voelker.de
- Update to version 2.10.6
  * bugfix release, see included CHANGELOG.txt for details
* Mon Oct 26 2015 lorddarthfener@gmail.com
- Update to version 2.10.4
  * bugfix release, see included CHANGELOG.txt for details
* Sun Sep 20 2015 lorddarthfener@gmail.com
- Update to version 2.10.2
  * new and improved LaTeX parser
  * improved search results window
  * open password protected pdfs
  * improved UI scaling
  * temporary highlight target text of go to definition
  * bugfixes
* Thu Apr 30 2015 dmitry_r@opensuse.org
- Update to version 2.9.4
  * bugfix release, see included CHANGELOG.txt for details
- Build with Qt5 for openSUSE > 13.2
* Sat Mar 14 2015 dmitry_r@opensuse.org
- Update to version 2.9.0
  * link overlays for urls
  * close editor tab by pressing middle mouse button
  * support optional filename argument in txs:///view-pdf-internal
  * add "expand/collapse all documents" to context menu of structure
  * add tabulary support
  * windowed pdf viewer now supports --no-focus argument
  * improved detection of label name for "Insert \ref to Next Label"
  * improved context detection for preview
  * improved search for texdoc location
  * improved log parsing including support for LaTeX3 warnings and errors
  * resize with soft line warp: keep vertical cursor position constant
  * support .tikz files (treated like .tex files)
  * bugfixes
* Thu Feb 26 2015 dmitry_r@opensuse.org
- Update to version 2.8.8, mostly bugfixes, see CHANGELOG.txt
- Drop texstudio-correct-doc-location.patch
* Fri Jun 20 2014 dmitry_r@opensuse.org
- Update to version 2.8.0
  * completion and syntax check on keyval options, e.g.
    \includegraphics (graphicx!)
  * search and replace over several documents improved
  * improved parser for log files (better detection of filenames)
  * todo-style commands (e.g. \todo{}) are added to the list of todos
  * the keyboard modifier key for the context menu (spellcheck
    suppression) is configurable via texstudio.ini
    "Editor/ContextMenuKeyboardModifiers"
  * improved auto-hide toolbars feature in embedded viewer
  * users can overwrite the default language definitions and add own ones
  * makeglossaries support
  * allow quoted filenames in include-like commands to support
    filenames and directories containing spaces
  * updated LaTeX reference manual
  * several bugfixes
* Fri Apr  4 2014 dmitry_r@opensuse.org
- Update to version 2.7.0
  * added Edit -> Text Operations (To Lowercase / To Uppercase / To Titlecase)
  * added list of recent sessions
  * speedup of saving for large documents
  * added recognition in filetree for import subimport importfrom
    and subimportfrom (Thanks to Steven Vandekerckhove)
  * added button to stop a running compilation
  * the dictionary search path can now contain of multiple directories
  * Dictionaries in the OpenOffice/LibreOffice Extension format
    (*.oxt) can now be imported
  * Updated the latex reference manual to to a recent version
  * new option for maximum image tooltip width
  * new option "Reference commands in context menu"
  * new options for additional search paths in editor logic
  * new option for automatic encoding detection: make latex and
    character based detection selectable separately
  * new options for pdf highlight color and duration
  * find dialog: search in all loaded documents i.e. also in hidden
  * improved synchonization PDF -> source
  * support "%% !BIB = biber" syntax for compatibility with TeXShop
    and TeXWorks
  * added several new cwl files
  * several bugfixes
- Set correct documentation location
  * texstudio-correct-doc-location.patch
* Wed Jun 12 2013 jsundermeyer@sf.net
- release (2.6.0)
* Fri Mar 29 2013 jsundermeyer@sf.net
- fix potential crash (2.5.2)
* Wed Dec  5 2012 jsundermeyer@sf.net
- bug fixes (2.5.2)
* Sat Dec  1 2012 mailaender@opensuse.org
- spec file cleanup, fixed some RPMlint warnings
* Wed Nov 21 2012 benito@benibela.de
- update to version 2.5.1
* Sun Oct 28 2012 benito@benibela.de
- update to version 2.5
* Fri Aug 31 2012 benito@benibela.de
- update to version 2.4
* Mon Feb  6 2012 benito@benibela.de
- update to version 2.3
* Wed Jul 20 2011 benito@benibela.de
- initial release of version 2.2
